Global Module Index — Chiplotle v0.1 documentation

### Navigation

- index
- modules |
- Chiplotle »
- Chiplotle v0.1 documentation »

# Global Module Index

C

| C |
| `chiplotle` |
| `chiplotle.hpgl.commands` |
| `chiplotle.plotters` |

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- Chiplotle »
- Chiplotle v0.1 documentation »

© Copyright 2009, Víctor Adán, Douglas Repetto. Created using Sphinx 0.6.2.